Found with <https://github.com/lyda/misspell-check>, except
"dictionnary" which is what prompted me to look for more.
---
 TODO                  |    2 +-
 monkeysign/gpg.py     |    4 ++--
 monkeysign/ui.py      |    2 +-
 tests/test_network.py |    4 ++--
 tests/test_ui.py      |    2 +-
 5 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/TODO b/TODO
index 7d864fa..389bac9 100644
--- a/TODO
+++ b/TODO
@@ -31,7 +31,7 @@ The merge question
 
 This software has a primitive GPG Python API that duplicates the work
 of at least two other libraries. The `pythong-gnupg` library is
-particularily similar and communication was started to consider the
+particularly similar and communication was started to consider the
 possibility of merging. This section details how we should deal with
 this.
 
diff --git a/monkeysign/ui.py b/monkeysign/ui.py
index b18b5ef..19fdef8 100644
--- a/monkeysign/ui.py
+++ b/monkeysign/ui.py
@@ -115,7 +115,7 @@ class MonkeysignUi(object):
         self.keyring = Keyring()
 
         # the temporary keyring we operate in, actually initialized in 
prepare()
-        # this is because we want the constructor to jsut initialise
+        # this is because we want the constructor to just initialise
         # data structures and not write any data
         self.tmpkeyring = None
 
diff --git a/tests/test_ui.py b/tests/test_ui.py
index deafd92..a102a8c 100755
--- a/tests/test_ui.py
+++ b/tests/test_ui.py
@@ -277,7 +277,7 @@ class FakeKeyringTests(BaseTestCase):
         """test if we can find a key on the local keyring"""
         self.ui.find_key()
 
-class NonExistantKeyTests(BaseTestCase, TestTimeLimit):
+class NonExistentKeyTests(BaseTestCase, TestTimeLimit):
     """test behavior with a key that can't be found"""
 
     args = []
diff --git a/monkeysign/gpg.py b/monkeysign/gpg.py
index 77b78a2..88769b0 100644
--- a/monkeysign/gpg.py
+++ b/monkeysign/gpg.py
@@ -138,12 +138,12 @@ class Context():
         sense.
 
         this uses build_command to create a commandline out of the
-        'options' dictionnary, and appends the provided command at the
+        'options' dictionary, and appends the provided command at the
         end. this is because order of certain options matter in gpg,
         where some options (like --recv-keys) are expected to be at
         the end.
 
         it is here that the options dictionnary is converted into a
         list. the command argument is expected to be a list of
         arguments that can be converted to strings. if it is not a
         list, it is cast into a list."""
@@ -138,12 +138,12 @@ class Context():
         the end.
 
-        it is here that the options dictionnary is converted into a
+        it is here that the options dictionary is converted into a
         list. the command argument is expected to be a list of
         arguments that can be converted to strings. if it is not a
diff --git a/tests/test_network.py b/tests/test_network.py
index 05df556..7cbb73f 100755
--- a/tests/test_network.py
+++ b/tests/test_network.py
@@ -18,7 +18,7 @@
 
 """Tests that hit the network.
 
-Those tests are in a seperate file to allow the base set of tests to
+Those tests are in a separate file to allow the base set of tests to
 be ran without internet access.
 """
 
@@ -32,7 +32,7 @@ from monkeysign.gpg import TempKeyring
 from test_lib import TestTimeLimit, AlarmException
 
 class TestGpgNetwork(TestTimeLimit):
     """Seperate test cases for functions that hit the network
 
 each test needs to run under a specific timeout so we don't wait on
 the network forever"""
@@ -32,7 +32,7 @@ from monkeysign.gpg import TempKeyring
 
 class TestGpgNetwork(TestTimeLimit):
-    """Seperate test cases for functions that hit the network
+    """Separate test cases for functions that hit the network
 
 each test needs to run under a specific timeout so we don't wait on
-- 
1.7.10.4


-- 
To UNSUBSCRIBE, email to debian-bugs-dist-requ...@lists.debian.org
with a subject of "unsubscribe". Trouble? Contact listmas...@lists.debian.org

Reply via email to